@@ -8,3 +8,8 @@ def get_value_from_dict(data: dict, key: str = None):
         for k in key_list:
             value = value.get(k)
     return value
+
+
+# 去空
+def eliminate_empty(list):
+    return [x for x in list if x is not None]
